@@ -1,10 +1,4 @@
-#include "Notes.h"
-
-#include "Note.h"
-
-#include "../Database.h"
-
-#include "../Data/Note.h"
+#include "View/Notes.h"
 
 #include <Lum/Base/Util.h>
 
@@ -14,30 +8,25 @@
 
 #include <Lum/Model/Selection.h>
 
+#include "Note.h"
+
+#include "../Database.h"
+
 #include <iostream>
 
 namespace Views {
 
-  class NotesEntry : public Lum::Model::ListTable::Entry
+  class NotesEntryDataProvider : public NotesEntryModel::DataProvider
   {
   public:
-    ::Data::NotePtr note;
-
-  public:
-    NotesEntry(Lum::Model::ListTable* table, ::Data::NotePtr note)
-    : Lum::Model::ListTable::Entry(table),note(note)
-    {
-      // no code
-    }
-
-    std::wstring GetString(size_t column) const
+    std::wstring GetString(const NotesEntryModel::Iterator& iter, size_t column) const
     {
       std::wstring result;
       size_t       pos;
 
       switch (column) {
       case 1:
-        result=note->GetAttribute(::Data::Note::NoteType::text);
+        result=(*iter)->note->GetAttribute(::Data::Note::NoteType::text);
         pos=result.find(L'\n');
         if (pos!=std::wstring::npos) {
           return result.substr(0,pos)+L"...";
@@ -49,21 +38,27 @@ namespace Views {
         return L"";
       }
     }
+  };
 
-    bool IsGreater(const Lum::Model::ListTable::Entry* other, size_t column) const
+  class NotesEntryComparator : public NotesEntryModel::Comparator
+  {
+  public:
+    bool operator()(const NotesEntryModel::ElementType& a,
+                    const NotesEntryModel::ElementType& b,
+                    size_t column, bool down) const
     {
-      ::Data::NotePtr tmp=dynamic_cast<const NotesEntry*>(other)->note;
-
-      return note->GetAttribute(::Data::Note::NoteType::text)>tmp->GetAttribute(::Data::Note::NoteType::text);
+      return a->note->GetAttribute(::Data::Note::NoteType::text)<b->note->GetAttribute(::Data::Note::NoteType::text);
     }
   };
 
+
   Notes::Notes()
   : View(L"Notes"),
     viewAction(new Lum::Model::Action),
     addAction(new Lum::Model::Action),
     deleteAction(new Lum::Model::Action),
-    model(new Lum::Model::ListTable()),
+    model(new NotesEntryModel(new NotesEntryDataProvider(),
+                              new NotesEntryComparator())),
     table(NULL),top(NULL)
   {
     Observe(viewAction);
@@ -89,7 +84,7 @@ namespace Views {
       ::Data::NotePtr note;
 
       if ((note=dynamic_cast< ::Data::NotePtr>(*iter))!=NULL) {
-        model->Append(new NotesEntry(model,note));
+        model->Append(new NotesEntry(note));
       }
 
       iter++;
