@@ -1,10 +1,4 @@
-#include "People.h"
-
-#include "Person.h"
-
-#include "../Database.h"
-
-#include "../Data/Person.h"
+#include "View/People.h"
 
 #include <Lum/Base/Util.h>
 
@@ -13,43 +7,42 @@
 
 #include <Lum/Model/Selection.h>
 
+#include "Person.h"
+
+#include "../Database.h"
+
 #include <iostream>
 
 namespace Views {
 
-  class PeopleEntry : public Lum::Model::ListTable::Entry
+  class PeopleEntryDataProvider : public PeopleEntryModel::DataProvider
   {
   public:
-    ::Data::PersonPtr person;
-
-  public:
-    PeopleEntry(Lum::Model::ListTable* table, ::Data::PersonPtr person)
-    : Lum::Model::ListTable::Entry(table),person(person)
-    {
-      // no code
-    }
-
-    std::wstring GetString(size_t column) const
+    std::wstring GetString(const PeopleEntryModel::Iterator& iter, size_t column) const
     {
       switch (column) {
       case 1:
-        return person->GetAttribute(::Data::Person::PersonType::name);
+        return (*iter)->person->GetAttribute(::Data::Person::PersonType::name);
       case 2:
-        return person->GetAttribute(::Data::Person::PersonType::surename);
+        return (*iter)->person->GetAttribute(::Data::Person::PersonType::surename);
       default:
         return L"";
       }
     }
+  };
 
-    bool IsGreater(const Lum::Model::ListTable::Entry* other, size_t column) const
+  class PeopleEntryComparator : public PeopleEntryModel::Comparator
+  {
+  public:
+    bool operator()(const PeopleEntryModel::ElementType& a,
+                    const PeopleEntryModel::ElementType& b,
+                    size_t column, bool down) const
     {
-      ::Data::PersonPtr tmp=dynamic_cast<const PeopleEntry*>(other)->person;
-
-      if (person->GetAttribute(::Data::Person::PersonType::name)==tmp->GetAttribute(::Data::Person::PersonType::name)) {
-        return person->GetAttribute(::Data::Person::PersonType::surename)>tmp->GetAttribute(::Data::Person::PersonType::surename);
+      if (a->person->GetAttribute(::Data::Person::PersonType::name)==b->person->GetAttribute(::Data::Person::PersonType::name)) {
+        return a->person->GetAttribute(::Data::Person::PersonType::surename)<b->person->GetAttribute(::Data::Person::PersonType::surename);
       }
       else {
-        return person->GetAttribute(::Data::Person::PersonType::name)>tmp->GetAttribute(::Data::Person::PersonType::name);
+        return a->person->GetAttribute(::Data::Person::PersonType::name)<b->person->GetAttribute(::Data::Person::PersonType::name);
       }
     }
   };
@@ -59,8 +52,10 @@ namespace Views {
     viewAction(new Lum::Model::Action),
     addAction(new Lum::Model::Action),
     deleteAction(new Lum::Model::Action),
-    model(new Lum::Model::ListTable()),
-    table(NULL),top(NULL)
+    model(new PeopleEntryModel(new PeopleEntryDataProvider(),
+                               new PeopleEntryComparator())),
+    table(NULL),
+    top(NULL)
   {
     Observe(viewAction);
     Observe(addAction);
@@ -85,7 +80,7 @@ namespace Views {
       ::Data::PersonPtr person;
 
       if ((person=dynamic_cast< ::Data::PersonPtr>(*iter))!=NULL) {
-        model->Append(new PeopleEntry(model,person));
+        model->Append(new PeopleEntry(person));
       }
 
       iter++;
